@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 
-''' Copyright 2012 Smartling, Inc.
+""" Copyright 2012 Smartling, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this work except in compliance with the License.
@@ -15,7 +15,7 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
-'''
+"""
 
 import sys
 
@@ -33,11 +33,6 @@ else:
 import mimetypes
 from io import IOBase
 
-class Callable:
-    def __init__(self, anycallable):
-        self.__call__ = anycallable
-
-
 class MultipartPostHandler(urllib2.BaseHandler):
     """ handler for multipart HTTP POST, helper object to provide POST functionality """
 
@@ -52,28 +47,29 @@ class MultipartPostHandler(urllib2.BaseHandler):
         else:
             return type(value) == file
 
-    def http_request(self, request):
+    def http_request(self, request, forceMultipart = False):
         if isPython3:
             data = request.data
         else:
             data = request.get_data()
-        if data is not None and type(data) != str:
-            v_files = []
-            v_vars = []
+
+        if data is not None and type(data) != str and type(data) != bytes:
+            files = []
+            vars = []
             try:
                 for(key, value) in list(data.items()):
                     if self.ifFileInstance(value):
-                        v_files.append((key, value))
+                        files.append((key, value))
                     else:
-                        v_vars.append((key, value))
+                        vars.append((key, value))
             except TypeError:
                 systype, value, traceback = sys.exc_info()
                 raise TypeError("not a valid non-string sequence or mapping object")(traceback)
 
-            if len(v_files) == 0:
-                data = urlencode(v_vars, self.doseq)
+            if (not forceMultipart) and len(files) == 0:
+                data = urlencode(vars, self.doseq)
             else:
-                boundary, data = self.multipart_encode(v_vars, v_files)
+                boundary, data = self.multipartEncode(vars, files)
                 contenttype = 'multipart/form-data; boundary=%s' % boundary
 
                 if(request.has_header('Content-Type')
@@ -88,16 +84,10 @@ class MultipartPostHandler(urllib2.BaseHandler):
                 request.add_data(data)
         return request
 
-    def multipart_encode(self, vars, files, boundary=None, buffer=None):
-        if boundary is None:
-            if isPython3:
-                boundary = mimetools._make_boundary()
-                boundary = boundary.replace("=", "-")
-            else:
-                boundary = mimetools.choose_boundary()
+    def multipartEncode(self, vars, files):
+        boundary = self.createBoundary()
 
-        if buffer is None:
-            buffer = ''
+        buffer = ''
         for(key, value) in vars:
             buffer += '--%s\r\n' % boundary
             buffer += 'Content-Disposition: form-data; name="%s"' % key
@@ -115,9 +105,19 @@ class MultipartPostHandler(urllib2.BaseHandler):
                 buffer += '\r\n' + fd.read() + '\r\n'
 
         if isPython3:
+            if str == type(buffer):
+                buffer = buffer.encode()
             buffer += b'--%b--\r\n\r\n' % boundary.encode()
         else:
             buffer += '--%s--\r\n\r\n' % boundary
         return boundary, buffer
 
+    def createBoundary(self):
+        if isPython3:
+            boundary = mimetools._make_boundary()
+            boundary = boundary.replace("=", "-")
+        else:
+            boundary = mimetools.choose_boundary()
+        return boundary
+
     https_request = http_request
